;***************************************************************************
; DEFINE SECTION
;***************************************************************************
; load vectrex bios routine definitions
                    INCLUDE  "VECTREX.I"                  ; vectrex function includes
SCALE               equ      $80 
HEIGHT              equ      -$1 
WIDTH               equ      $30 
XPOS                equ      -$80 
YPOS                equ      -$50 
;***************************************************************************
; Variable / RAM SECTION
;***************************************************************************
; insert your variables (RAM usage) in the BSS section
; user RAM starts at $c880 
                    BSS      
                    ORG      $c880                        ; start of our ram space 
;***************************************************************************
; HEADER SECTION
;***************************************************************************
; The cartridge ROM starts at address 0
                    CODE     
                    ORG      0 
; the first few bytes are mandatory, otherwise the BIOS will not load
; the ROM file, and will start MineStorm instead
                    DB       "g GCE 2016", $80 ; 'g' is copyright sign
                    DW       music1                       ; music from the rom 
                    DB       $F8, $50, $20, -$80          ; hight, width, rel y, rel x (from 0,0) 
                    DB       "RASTER EXAMPLE UNI", $80    ; some game information, ending with $80
                    DB       0                            ; end of game header 
;***************************************************************************
; CODE SECTION
;***************************************************************************
; here the cartridge program starts off
                    lda      #WIDTH 
                    sta      Vec_Text_Width 
                    lda      #HEIGHT 
                    sta      Vec_Text_Height 
main: 
                    JSR      Wait_Recal                   ; Vectrex BIOS recalibration 
                    JSR      Intensity_5F                 ; Sets the intensity of the 
                                                          ; vector beam to $5f 
                    lda      #SCALE 
                    sta      <VIA_t1_cnt_lo 
                    LDA      #YPOS                        ; Text position relative Y 
                    LDB      #XPOS                        ; Text position relative X 
                    LDU      #test1 
                    JSR      sync_Print_Str_d             ; Vectrex BIOS print routine 
                    LDA      #YPOS-$b                     ; Text position relative Y 
                    LDB      #XPOS                        ; Text position relative X 
                    LDU      #test2 
                    JSR      sync_Print_Str_d             ; Vectrex BIOS print routine 
                    LDA      #YPOS-$b*2                   ; Text position relative Y 
                    LDB      #XPOS                        ; Text position relative X 
                    LDU      #test3 
                    JSR      sync_Print_Str_d             ; Vectrex BIOS print routine 
                    LDA      #YPOS-$b*3                   ; Text position relative Y 
                    LDB      #XPOS                        ; Text position relative X 
                    LDU      #test4 
                    JSR      sync_Print_Str_d             ; Vectrex BIOS print routine 
;X = (y,x) position of vectorlist (this will be point 0,0), positioning on screen
;A = scalefactor "Move" (after sync)
;B = scalefactor "Vector" (vectors in vectorlist)
;U = address of vectorlist
                    ldx      #$3000 
                    lda      #$80 
                    ldb      #$50 
                    LDU      #ForestSync 
                    JSR      draw_synced_list             ; Vectrex BIOS print routine 
                    BRA      main                         ; and repeat forever 

test1: 
                    db       "To the south you see a witch hut.", $80
test2: 
                    db       "North is a forboding forest.", $80
test3: 
                    db       "A trail leads from east to west.", $80
test4: 
                    db       "What do you do?", $80
;***************************************************************************
; DATA SECTION
;***************************************************************************
                    include  "font_5.asm"
                    include  "locations.asm"


MY_MOVE_TO_D        macro    
; optimzed, tweaked not perfect... 'MOVE TO D' makro
;
;
; NOT DONE:
;
; what should be done:
; s = $ff / max(abs(a),abs(b))
; a = a * s
; b = b * s
; scaling = scaling / s
;
; that would give the most efficient positioning
; bother it takes more time to calculate the above,
; than it saves
; with every positioning via this routine now,
; it takes SCALE_FACTOR_GAME + const (of another 100+) cycles
; to do one simple positioning!!!
; that is probably about 300 cycles per positioning
; this is done about 30-40 times per round
; alone the positioning takes thus about over 10000 cycles
; and we haven't drawn a single line yet!!!
                    local    LF33D 
                    STA      <VIA_port_a                  ;Store Y in D/A register 
                    LDA      #$CE                         ;Blank low, zero high? 
                    STA      <VIA_cntl                    ; 
                    CLRA     
                    STA      <VIA_port_b                  ;Enable mux 
                    STA      <VIA_shift_reg               ;Clear shift regigster 
                    INC      <VIA_port_b                  ;Disable mux 
                    STB      <VIA_port_a                  ;Store X in D/A register 
                    STA      <VIA_t1_cnt_hi               ;enable timer 
                    LDB      #$40                         ; 
LF33D:              BITB     <VIA_int_flags               ; 
                    BEQ      LF33D                        ; 
                    endm     



                    include  "printStringSync.asm"
                    include  "drawSyncList.asm"
